@@ -4,6 +4,8 @@
 
 #include <QQmlExtensionPlugin>
 #include <QQmlEngine>
+#include "nameutils.h"
+#include "messagedialoghelper.h"
 
 class ComponentsPlugin : public QQmlExtensionPlugin
 {
@@ -26,6 +28,13 @@ void ComponentsPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
 void ComponentsPlugin::registerTypes(const char *uri)
 {
     qmlRegisterModule(uri, 1, 0);
+    qmlRegisterSingletonType<NameUtils>(uri, 1, 0, "NameUtils", [](QQmlEngine*, QJSEngine*) -> QObject* {
+        return new NameUtils;
+    });
+
+    qmlRegisterSingletonType<MessageDialogHelper>(uri, 1, 0, "MessageDialogHelper", [](QQmlEngine*, QJSEngine*) -> QObject* {
+        return new MessageDialogHelper;
+    });
 }
 
 #include "componentsplugin.moc"
